@@ -1,14 +1,15 @@
+import json
+import shutil
+import tarfile
+from collections import defaultdict
+
+import numpy as np
+
 import seisbench
 import seisbench.util
+
 from .base import BenchmarkDataset
 
-import json
-import tarfile
-import numpy as np
-from collections import defaultdict
-import shutil
-
-
 # Conversion from earth radius
 DEG2KM = 2 * np.pi * 6371 / 360
 
@@ -109,7 +110,7 @@ class NEIC(BenchmarkDataset):
         tar_files = [x for x in path_original.iterdir() if x.name.endswith(".tar.gz")]
         for tar_path in tar_files:
             with tarfile.open(tar_path, "r:gz") as file:
-                file.extractall(path_unpacked)
+                seisbench.util.safe_extract_tar(file, path_unpacked)
 
         groups = [("P", "Train"), ("S", "Train"), ("P", "Test"), ("S", "Test")]
 
